==> keycloak-model-map-20.0.3-sources.jar: org/keycloak/models/map/realm/entity/MapComponentEntityFields.java <==
package org.keycloak.models.map.realm.entity;
public enum MapComponentEntityFields implements org.keycloak.models.map.common.EntityField<org.keycloak.models.map.realm.entity.MapComponentEntity> {
    ID {
        public static final String FIELD_NAME = "Id";
        public static final String FIELD_NAME_DASHED = "id";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.realm.entity.MapComponentEntity e) {
            return (String) e.getId();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.realm.entity.MapComponentEntity e, T value) {
            e.setId((String) value);
        }
    },
    CONFIG {
        public static final String FIELD_NAME = "Config";
        public static final String FIELD_NAME_DASHED = "config";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return java.util.Map.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public java.util.Map<String,java.util.List<String>> get(org.keycloak.models.map.realm.entity.MapComponentEntity e) {
            return (java.util.Map<String,java.util.List<String>>) e.getConfig();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.realm.entity.MapComponentEntity e, T value) {
            e.setConfig((java.util.Map<String,java.util.List<String>>) value);
        }
    },
    NAME {
        public static final String FIELD_NAME = "Name";
        public static final String FIELD_NAME_DASHED = "name";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.realm.entity.MapComponentEntity e, T value) {
            e.setName((String) value);
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.realm.entity.MapComponentEntity e) {
            return (String) e.getName();
        }
    },
    PARENT_ID {
        public static final String FIELD_NAME = "ParentId";
        public static final String FIELD_NAME_DASHED = "parent-id";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.realm.entity.MapComponentEntity e) {
            return (String) e.getParentId();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.realm.entity.MapComponentEntity e, T value) {
            e.setParentId((String) value);
        }
    },
    PROVIDER_ID {
        public static final String FIELD_NAME = "ProviderId";
        public static final String FIELD_NAME_DASHED = "provider-id";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.realm.entity.MapComponentEntity e, T value) {
            e.setProviderId((String) value);
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.realm.entity.MapComponentEntity e) {
            return (String) e.getProviderId();
        }
    },
    PROVIDER_TYPE {
        public static final String FIELD_NAME = "ProviderType";
        public static final String FIELD_NAME_DASHED = "provider-type";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.realm.entity.MapComponentEntity e) {
            return (String) e.getProviderType();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.realm.entity.MapComponentEntity e, T value) {
            e.setProviderType((String) value);
        }
    },
    SUB_TYPE {
        public static final String FIELD_NAME = "SubType";
        public static final String FIELD_NAME_DASHED = "sub-type";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.realm.entity.MapComponentEntity e, T value) {
            e.setSubType((String) value);
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.realm.entity.MapComponentEntity e) {
            return (String) e.getSubType();
        }
    },
}

==> keycloak-model-map-21.0.0-sources.jar: org/keycloak/models/map/realm/entity/MapComponentEntityFields.java <==
package org.keycloak.models.map.realm.entity;
@javax.annotation.processing.Generated("org.keycloak.models.map.processor.GenerateEntityImplementationsProcessor")
public enum MapComponentEntityFields implements org.keycloak.models.map.common.EntityField<org.keycloak.models.map.realm.entity.MapComponentEntity> {
    ID {
        public static final String FIELD_NAME = "Id";
        public static final String FIELD_NAME_DASHED = "id";
        public static final String FIELD_NAME_CAMEL_CASE = "id";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @Override public String getNameCamelCase() {
            return FIELD_NAME_CAMEL_CASE;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.realm.entity.MapComponentEntity e, T value) {
            e.setId((String) value);
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.realm.entity.MapComponentEntity e) {
            return (String) e.getId();
        }
    },
    CONFIG {
        public static final String FIELD_NAME = "Config";
        public static final String FIELD_NAME_DASHED = "config";
        public static final String FIELD_NAME_CAMEL_CASE = "config";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return java.util.Map.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @Override public String getNameCamelCase() {
            return FIELD_NAME_CAMEL_CASE;
        }
        @SuppressWarnings("unchecked") @Override public Class<?> getMapKeyClass() {
            return String.class;
        }
        @SuppressWarnings("unchecked") @Override public Class<?> getMapValueClass() {
            return java.util.List.class;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.realm.entity.MapComponentEntity e, T value) {
            e.setConfig((java.util.Map<String,java.util.List<String>>) value);
        }
        @SuppressWarnings("unchecked") @Override public java.util.Map<String,java.util.List<String>> get(org.keycloak.models.map.realm.entity.MapComponentEntity e) {
            return (java.util.Map<String,java.util.List<String>>) e.getConfig();
        }
    },
    NAME {
        public static final String FIELD_NAME = "Name";
        public static final String FIELD_NAME_DASHED = "name";
        public static final String FIELD_NAME_CAMEL_CASE = "name";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @Override public String getNameCamelCase() {
            return FIELD_NAME_CAMEL_CASE;
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.realm.entity.MapComponentEntity e) {
            return (String) e.getName();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.realm.entity.MapComponentEntity e, T value) {
            e.setName((String) value);
        }
    },
    PARENT_ID {
        public static final String FIELD_NAME = "ParentId";
        public static final String FIELD_NAME_DASHED = "parent-id";
        public static final String FIELD_NAME_CAMEL_CASE = "parentId";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @Override public String getNameCamelCase() {
            return FIELD_NAME_CAMEL_CASE;
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.realm.entity.MapComponentEntity e) {
            return (String) e.getParentId();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.realm.entity.MapComponentEntity e, T value) {
            e.setParentId((String) value);
        }
    },
    PROVIDER_ID {
        public static final String FIELD_NAME = "ProviderId";
        public static final String FIELD_NAME_DASHED = "provider-id";
        public static final String FIELD_NAME_CAMEL_CASE = "providerId";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @Override public String getNameCamelCase() {
            return FIELD_NAME_CAMEL_CASE;
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.realm.entity.MapComponentEntity e) {
            return (String) e.getProviderId();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.realm.entity.MapComponentEntity e, T value) {
            e.setProviderId((String) value);
        }
    },
    PROVIDER_TYPE {
        public static final String FIELD_NAME = "ProviderType";
        public static final String FIELD_NAME_DASHED = "provider-type";
        public static final String FIELD_NAME_CAMEL_CASE = "providerType";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @Override public String getNameCamelCase() {
            return FIELD_NAME_CAMEL_CASE;
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.realm.entity.MapComponentEntity e) {
            return (String) e.getProviderType();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.realm.entity.MapComponentEntity e, T value) {
            e.setProviderType((String) value);
        }
    },
    SUB_TYPE {
        public static final String FIELD_NAME = "SubType";
        public static final String FIELD_NAME_DASHED = "sub-type";
        public static final String FIELD_NAME_CAMEL_CASE = "subType";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @Override public String getNameCamelCase() {
            return FIELD_NAME_CAMEL_CASE;
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.realm.entity.MapComponentEntity e) {
            return (String) e.getSubType();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.realm.entity.MapComponentEntity e, T value) {
            e.setSubType((String) value);
        }
    },
}
